@@ -132,7 +132,7 @@ void MainProg::updatestatuslinecontent()
 	    wstatus->appendstring(attrBG, " Enter Info");
 	}
 	wstatus->appendstring(attrWG, " |");
-	wstatus->appendstring(attrYG, " F9");
+	wstatus->appendstring(attrYG, " F9/M");
 	wstatus->appendstring(attrWG, " Menu |");
 	wstatus->appendstring(attrYG, " V");
 	wstatus->appendstring(attrWG, " Statistics |");
@@ -165,12 +165,24 @@ void MainProg::eventhandle(NEvent* ev)	//обработчик событий К
 		wmain->updatecaption();
         }
 		break;
+		    case 'p':
+            case 'P':
+                menu->disable();
+                if (gsrvlist->getcursrv())
+                {
+                    gsrvlist->prevserver();
+                    wmain->setserver(gsrvlist->getcursrv());
+                    menu->setserver(gsrvlist->getcursrv());
+                    evtimertime = 0;
+                    wmain->updatecaption();
+                }
+                break;
 	    case 'c':
 	    case 'C':
 		if (getitembyid(typeid(CfgForm).name()) == NULL)
 		{
 		    menu->disable();
-		    CfgForm* cfgform = new CfgForm(15,54/*,cfg*/);
+		    CfgForm* cfgform = new CfgForm(15,76/*,cfg*/);
 		    insert(cfgform);
 		    cfgform->settitle("Configuration");
 		    cfgform->refresh();
@@ -237,6 +249,8 @@ void MainProg::eventhandle(NEvent* ev)	//обработчик событий К
 		uistate = uistate & ~stUIMODALFORM;
 		updatestatuslinecontent();
 		break;
+		case 'M':
+	    case 'm':
 	    case KEY_F(9):
 		if (!menu->isenable())
 		{
@@ -446,6 +460,20 @@ void MainProg::eventhandle(NEvent* ev)	//обработчик событий К
 		refresh();
 		break;
 	    }
+		case evTRANSPARENTBGMODECHANGE:
+	    {
+			gCfg->setivalue("transparent_background",(transparentbg==0)?1:0);
+			//transparentbg = (transparentbg==0)?1:0;
+			//refresh();
+		    menu->disable(); //выключаем меню
+		    //создаем окно сообщения с подтверждением
+		    NMessageBox* mbox = new NMessageBox("Need restart boinctui");
+		    NEvent* buttonNev = new NEvent(NEvent::evKB, 27); //событие для кнопки N
+		    mbox->addbutton(new NMButton("Yes",buttonNev, 'Y','y','\n',27,0));
+		    insert(mbox);
+		    uistate = uistate | stUIMODALFORM;
+			break;
+	    }
 	} //switch
     }
 }
