@@ -145,16 +145,20 @@ void SrvList::refreshcfg() //перечитать из конфига
     std::vector<Item*>::iterator it;
     for (it = slist.begin(); it != slist.end(); it++)
     {
-	Item* host = (*it)->findItem("host");
-	Item* port = (*it)->findItem("port");
-	Item* pwd = (*it)->findItem("pwd");
-	if ((host != NULL)&&(port != NULL))
-	{
-	    if (pwd == NULL)
-		servers.push_back(new Srv(host->getsvalue(), port->getsvalue(), ""));
-	    else
-		servers.push_back(new Srv(host->getsvalue(), port->getsvalue(), pwd->getsvalue()));
-	}
+        Item* host = (*it)->findItem("host");
+        Item* port = (*it)->findItem("port");
+        Item* pwd = (*it)->findItem("pwd");
+        Item* hostid = (*it)->findItem("hostid");
+        if ((host != NULL)&&(port != NULL))
+        {
+            std::string spwd="";
+            if(pwd!=NULL)
+                spwd=pwd->getsvalue();
+            std::string shostid="";
+            if(hostid!=NULL)
+                shostid=hostid->getsvalue();
+            servers.push_back(new Srv(host->getsvalue(), port->getsvalue(), spwd.c_str(), shostid.c_str()));
+        }
     }
     if (!servers.empty())
     {
@@ -188,13 +192,26 @@ void SrvList::nextserver() //переключиться на след серве
     (*cursrv)->setactive(true); //активиркем тред
 }
 
+void SrvList::prevserver()
+{
+    (*cursrv)->setactive(false);
+    if (cursrv == servers.begin())
+    {
+        cursrv = servers.end();
+        cursrv--;
+    }
+    else
+        cursrv--;
+    (*cursrv)->setactive(true);
+}
 //=============================================================================================
 
 
-Srv::Srv(const char* shost, const char* sport, const char* pwd) : TConnect(shost, sport)
+Srv::Srv(const char* shost, const char* sport, const char* pwd, const char* hostid) : TConnect(shost, sport)
 {
     allprojectsdom = NULL;
     this->pwd = strdup(pwd);
+    this->hostid = strdup(hostid);
     lastmsgno = 0;
     active = false;
     loginfail = false;
@@ -214,6 +231,7 @@ Srv::~Srv()
     }
     if (allprojectsdom != NULL) delete allprojectsdom;
     if (pwd != NULL) delete pwd;
+    if (hostid != NULL) delete hostid;
     pthread_mutex_destroy(&mutex);
     kLogPrintf("-Srv::~Srv()\n");
 }
@@ -518,7 +536,7 @@ bool Srv::createaccount(const char* url, const char* email, const char* pass, co
     for (int i=0;i<MD5_DIGEST_LENGTH;i++)
 	sprintf(shash+i*2,"%02x",md5digest[i]);
     //формируем запрос для создания аккаунта
-    char sreq[1024];
+    char sreq[2048];
     snprintf(sreq,sizeof(sreq),
         "<create_account>\n"
         "   <url>%s</url>\n"
@@ -574,7 +592,7 @@ bool Srv::projectattach(const char* url, const char* prjname, const char* email,
     for (int i=0;i<MD5_DIGEST_LENGTH;i++)
 	sprintf(shash+i*2,"%02x",md5digest[i]);
     //формируем запрос для получения authenticator
-    char sreq[1024];
+    char sreq[2048];
     snprintf(sreq,sizeof(sreq),"<lookup_account>\n<url>%s</url>\n<email_addr>%s</email_addr>\n<passwd_hash>%s</passwd_hash>\n</lookup_account>\n",url,email,shash);
     Item* res = req(sreq);
     if (res == NULL)
