@@ -30,6 +30,7 @@
 #define M_HELP				"Help"
 //Названия пунктов меню "File"
 #define M_NEXT_HOST			"Next BOINC host"
+#define M_PREV_HOST			"Prev BOINC host"
 #define M_CONFIG_HOSTS			"Configure host list"
 #define M_VIEW_STATS			"View Statistics"
 #define M_RUN_BENCHMARKS		"Run CPU benchmarks"
@@ -40,8 +41,10 @@
 #define M_VIEW_DONE			"Percent done column"
 #define M_VIEW_PROJECT			"Project name column"
 #define M_VIEW_ESTIMATE			"Estimate time column"
+#define M_VIEW_RCV              "Receive time column"
 #define M_VIEW_DEADLINE			"Deadline time column"
 #define M_VIEW_APPNAME			"Application name column"
+#define M_VIEW_SWAP             "Swap size column"
 #define M_VIEW_TASKNAME			"Task name column"
 #define M_ALL_TASKS			"All tasks"
 #define M_HIDE_DONE			"Hide done tasks"
@@ -51,10 +54,13 @@
 #define M_SORT_BY_DONE			"Sort by done %"
 #define M_SORT_BY_PROJECT		"Sort by project name"
 #define M_SORT_BY_ESTIMATE		"Sort by estimate time"
+#define M_SORT_BY_RCV           "Sort by receive time"
 #define M_SORT_BY_DL			"Sort by deadline"
 #define M_SORT_BY_APP			"Sort by application"
+#define M_SORT_BY_SWAP          "Sort by swap size"
 #define M_SORT_BY_TASK			"Sort by task name"
 #define M_ASCII_LINE_DRAW		"ASCII line draw"
+#define M_TRANSPARENT_BG        "Transparent background"
 //Названия пунктов меню "Projects"
 #define M_ADD_PROJECT			"Add project"
 #define M_ADD_PROJECT_BY_URL	"Add project by URL"
@@ -231,6 +237,7 @@ void TopMenu::eventhandle(NEvent* ev) 	//обработчик событий
 FileSubMenu::FileSubMenu(NRect rect) : NMenu(rect)
 {
     additem(M_NEXT_HOST,"  N");
+    additem(M_PREV_HOST,"  P");
     additem(M_CONFIG_HOSTS,"  C");
     additem(M_VIEW_STATS,"  V");
     additem(M_RUN_BENCHMARKS,"");
@@ -244,6 +251,8 @@ bool FileSubMenu::action()
     putevent(new NEvent(NEvent::evKB, KEY_F(9))); //закрыть осн меню
     if ( strcmp(item_name(current_item(menu)),M_NEXT_HOST) == 0 )
 	putevent(new NEvent(NEvent::evKB, 'N')); //создаем событие иммитирующее нажатие 'N'
+    if ( strcmp(item_name(current_item(menu)),M_PREV_HOST) == 0 )
+        putevent(new NEvent(NEvent::evKB, 'P'));
     if ( strcmp(item_name(current_item(menu)),M_CONFIG_HOSTS) == 0 )
 	putevent(new NEvent(NEvent::evKB, 'C')); //создаем событие иммитирующее нажатие 'C'
     if ( strcmp(item_name(current_item(menu)),M_VIEW_STATS) == 0 )
@@ -267,8 +276,10 @@ ViewSubMenu::ViewSubMenu(NRect rect/*, Config* cfg*/) : NMenu(rect)
     additem(M_VIEW_DONE, iscolenable(/*cfg,*/colnum++) ? "[*]" : "[ ]");
     additem(M_VIEW_PROJECT, iscolenable(/*cfg,*/colnum++) ? "[*]" : "[ ]");
     additem(M_VIEW_ESTIMATE, iscolenable(/*cfg,*/colnum++) ? "[*]" : "[ ]");
+    additem(M_VIEW_RCV, iscolenable(/*cfg,*/colnum++) ? "[*]" : "[ ]");
     additem(M_VIEW_DEADLINE, iscolenable(/*cfg,*/colnum++) ? "[*]" : "[ ]");
     additem(M_VIEW_APPNAME, iscolenable(/*cfg,*/colnum++) ? "[*]" : "[ ]");
+    additem(M_VIEW_SWAP, iscolenable(/*cfg,*/colnum++) ? "[*]" : "[ ]");	
     additem(M_VIEW_TASKNAME, iscolenable(/*cfg,*/colnum++) ? "[*]" : "[ ]");
     additem("","");
     int taskslistmode = 0;
@@ -299,12 +310,15 @@ ViewSubMenu::ViewSubMenu(NRect rect/*, Config* cfg*/) : NMenu(rect)
     additem(M_SORT_BY_STATE,    (taskssortmode == 1) ? "(*)" : "( )");
     additem(M_SORT_BY_DONE,     (taskssortmode == 2) ? "(*)" : "( )");
     additem(M_SORT_BY_PROJECT,  (taskssortmode == 3) ? "(*)" : "( )");
-    additem(M_SORT_BY_ESTIMATE, (taskssortmode == 4) ? "(*)" : "( )");
-    additem(M_SORT_BY_DL,       (taskssortmode == 5) ? "(*)" : "( )");
-    //additem(M_SORT_BY_APP,      (taskssortmode == 6) ? "(*)" : "( )");  //not implemented yet
-    additem(M_SORT_BY_TASK,     (taskssortmode == 7) ? "(*)" : "( )");
+    additem(M_SORT_BY_RCV,  (taskssortmode == 4) ? "(*)" : "( )");
+    additem(M_SORT_BY_ESTIMATE, (taskssortmode == 5) ? "(*)" : "( )");
+    additem(M_SORT_BY_DL,       (taskssortmode == 6) ? "(*)" : "( )");
+    //additem(M_SORT_BY_APP,      (taskssortmode == 7) ? "(*)" : "( )");  //not implemented yet
+    additem(M_SORT_BY_SWAP,  (taskssortmode == 8) ? "(*)" : "( )");
+    additem(M_SORT_BY_TASK,     (taskssortmode == 9) ? "(*)" : "( )");
     additem("","");
     additem(M_ASCII_LINE_DRAW,  (asciilinedraw == 1) ? "[*]" : "[ ]");
+    additem(M_TRANSPARENT_BG,  (transparentbg == 1) ? "[*]" : "[ ]");
     additem(NULL,NULL);
 }
 
@@ -373,30 +387,42 @@ bool ViewSubMenu::action()
 	return true;
     }
 
-    if ( strcmp(item_name(current_item(menu)), M_SORT_BY_ESTIMATE) == 0 )
+    if ( strcmp(item_name(current_item(menu)), M_SORT_BY_RCV) == 0 )
     {
-	putevent(new TuiEvent(evSORTMODECH, 4));
-	return true;
+		putevent(new TuiEvent(evSORTMODECH, 4));
+		return true;
     }
 
-    if ( strcmp(item_name(current_item(menu)), M_SORT_BY_DL) == 0 )
+    if ( strcmp(item_name(current_item(menu)), M_SORT_BY_ESTIMATE) == 0 )
     {
 	putevent(new TuiEvent(evSORTMODECH, 5));
 	return true;
     }
 
-    if ( strcmp(item_name(current_item(menu)), M_SORT_BY_APP) == 0 )
+    if ( strcmp(item_name(current_item(menu)), M_SORT_BY_DL) == 0 )
     {
 	putevent(new TuiEvent(evSORTMODECH, 6));
 	return true;
     }
 
-    if ( strcmp(item_name(current_item(menu)), M_SORT_BY_TASK) == 0 )
+    if ( strcmp(item_name(current_item(menu)), M_SORT_BY_APP) == 0 )
     {
 	putevent(new TuiEvent(evSORTMODECH, 7));
 	return true;
     }
 
+    if ( strcmp(item_name(current_item(menu)), M_SORT_BY_SWAP) == 0 )
+    {
+		putevent(new TuiEvent(evSORTMODECH, 8));
+		return true;
+    }
+
+    if ( strcmp(item_name(current_item(menu)), M_SORT_BY_TASK) == 0 )
+    {
+	putevent(new TuiEvent(evSORTMODECH, 9));
+	return true;
+    }
+
     if ( strcmp(item_name(current_item(menu)), M_ASCII_LINE_DRAW) == 0 )
     {
 	asciilinedraw = !asciilinedraw;
@@ -404,6 +430,12 @@ bool ViewSubMenu::action()
 	return true;
     }
 
+    if ( strcmp(item_name(current_item(menu)), M_TRANSPARENT_BG) == 0 )
+    {
+		putevent(new TuiEvent(evTRANSPARENTBGMODECHANGE));
+		return true;
+    }
+
     putevent(new TuiEvent(evCOLVIEWCH,item_index(current_item(menu)), false));
     return true;
 }
